import asyncio
import logging
import sys

from pyflowery.models import FloweryAPIConfig
from pyflowery.pyflowery import FloweryAPI

root = logging.getLogger()
root.setLevel(logging.DEBUG)

handler = logging.StreamHandler(sys.stdout)
handler.setLevel(logging.DEBUG)
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
handler.setFormatter(formatter)
root.addHandler(handler)

api = FloweryAPI(FloweryAPIConfig(user_agent="PyFloweryTests"))

ALEXANDER = "fa3ea565-121f-5efd-b4e9-59895c77df23" # TikTok
JACOB = "38f45366-68e8-5d39-b1ef-3fd4eeb61cdb" # Microsoft Azure
STORMTROOPER = "191c5adc-a092-5eea-b4ff-ce01f66153ae" # TikTok

async def test_fetch_tts():
    """Test the fetch_tts method"""
    voice = api.get_voices(voice_id=ALEXANDER)[0]
    tts = await api.fetch_tts(text="Sphinx of black quartz, judge my vow. The quick brown fox jumps over a lazy dog.", voice=voice)
    try:
        with open('test.mp3', 'wb') as f:
            f.write(tts)
    except Exception as e: # pylint: disable=broad-except
        api.config.logger.error(e, exc_info=True)
    long_string = 'a' * 2049
    try:
        await api.fetch_tts(text=long_string)
    except ValueError as e:
        api.config.logger.error("This is expected to fail:\n%s", e, exc_info=True)

if __name__ == '__main__':
    api.config.logger.info("testing fetch_tts")
    asyncio.run(test_fetch_tts())



from dataclasses import dataclass, field
from logging import Logger, getLogger
from sys import version as pyversion
from typing import Dict, List, Union

from pyflowery.version import VERSION


@dataclass
class Voice:
    """Voice object returned from the Flowery API

    Attributes:
        id (str): UUID of the voice
        name (str): Name of the voice
        gender (str): Gender of the voice
        source (str): Source of the voice
        language (Language): Language object
    """
    id: str
    name: str
    gender: str
    source: str
    language: 'Language'

@dataclass
class Language:
    """Language object returned from the Flowery API

    Attributes:
        name (str): Name of the language
        code (str): Code of the language
    """
    name: str
    code: str

@dataclass
class Result:
    """Result returned from low-level RestAdapter

    Attributes:
        success (bool): Boolean of whether the request was successful
        status_code (int): Standard HTTP Status code
        message (str = ''): Human readable result
        data (Union[List[Dict], Dict, bytes]): Python List of Dictionaries (or maybe just a single Dictionary on error), can also be a ByteString
    """
    success: bool
    status_code: int
    message: str = ''
    data: Union[List[Dict], Dict, bytes] = field(default_factory=dict)


@dataclass
class FloweryAPIConfig:
    """Configuration for the Flowery API

    Attributes:
        user_agent (str): User-Agent string to use for the HTTP requests. Required as of 2.1.0.
        logger (Logger): Logger to use for logging messages
        allow_truncation (bool): Whether to allow truncation of text that is too long, defaults to `True`
        retry_limit (int): Number of times to retry a request before giving up, defaults to `3`
        interval (int): Seconds to wait between each retried request, multiplied by how many attempted requests have been made, defaults to `5`
    """
    user_agent: str
    logger: Logger = getLogger('pyflowery')
    allow_truncation: bool = False
    retry_limit: int = 3
    interval: int = 5

    def prepended_user_agent(self) -> str:
        """Return the user_agent with the PyFlowery module version prepended"""
        return f"PyFlowery/{VERSION} {self.user_agent} (Python {pyversion})"
